@@ -45,24 +45,18 @@ def sync(last_date, product_ese):
     """Mise à jour de la liste des clients Business ainsi que de leurs \
     relevés de consommation superieur a une date."""
     if not product_ese:
-        click.echo('not product_ese')
         products = Product.all()
-        click.echo(products)
         for product in products:
             product.update_customers()
             f = partial(core.update_customer_cdr, last_date)
             with Pool(processes=2) as pool:
-                click.echo(product.customers)
                 pool.map(f, product.customers)
     else:
-        click.echo('product_ese')
         product_eses = Product.all_ese()
         for product in product_eses:
-            click.echo(product)
             product.update_customers(product_ese=product_ese)
             f = partial(core.update_customer_cdr, last_date)
             with Pool(processes=2) as pool:
-                click.echo(product.customers_ese)
                 pool.map(f, product.customers_ese)
 
 
@@ -118,6 +112,58 @@ def notify(start_date, stop_date):
             s.quit()
 
 
+@cmd.command()
+@click.option('--start-date', default=False)
+@click.option('--stop-date', default=False)
+def notify_try(start_date, stop_date):
+    """Commande pour notifier les clients grand public \
+    selon leur niveau de consommation"""
+    click.echo('Récupération des données depuis Bluebase')
+    msg_client = ' '
+    product_types = CONFIG['PRODUCT_TRY']['product_type'].split(',')
+    for product_type in product_types:
+        customers = Product_GP.all(product_type)
+        for customer in customers:
+            click.echo('Notification du client {}'.format(customer.ident))
+            url = core.database_url(**FUPDB_CREDENTIALS)
+            with records.Database(url) as db:
+                sql = "SELECT refnum, product FROM customer WHERE name=:name"
+                rows = db.query(sql, name=customer.ident.lower())
+                row = rows.first()
+                if not row and customer.type_ident.lower() == 'ident':
+                    msg_client += "Le client {name} n'existe pas.\n".format(
+                        name=customer.ident.lower()
+                        )
+                    click.echo('customer {} exist pas'.format(
+                        customer.ident.lower()
+                        ))
+                else:
+                    response = customer.notify_try(start_date, stop_date)
+                    if not response:
+                        click.echo("Pas de notification à envoyer")
+                    else:
+                        medium, percentage, status = response
+                        msg = '{}: {}%'.format(medium, round(percentage))
+                        if status:
+                            msg = '{} ({})'.format(msg, 'Notification envoyée')
+                        click.echo(msg)
+        if msg_client.strip() != '':
+            dest = CONFIG['ALERT']['to_1']
+            content = MIMEText(msg_client, 'plain', 'utf-8')
+            msg = MIMEMultipart()
+            msg['Subject'] = '[blueline] customer inconnu'
+            msg['From'] = CONFIG['ALERT']['from']
+            msg['To'] = CONFIG['ALERT']['to_1']
+            msg.attach(content)
+            s = smtplib.SMTP('localhost')
+            s.sendmail(
+                CONFIG['ALERT']['from'],
+                dest.split(','),
+                msg.as_string()
+                )
+            s.quit()
+
+
 @cmd.command()
 @click.option('--product', is_flag=True, default=False)
 def reconciled(product):
