@@ -250,21 +250,23 @@ class Customer(object):
         params = {}
         params['customer'] = self.name
         if bool_defup:
+            method = 'delete'
             msg = 'Defup'
             db_status = False
         else:
+            method = 'post'
             msg = 'Fup'
             db_status = True
         customer_status = self.fup_status
         for policy_name in self.product.policies:
             status = customer_status.get(policy_name)
             policy_name_tab = policy_name.rsplit('_', 1)
-            method = 'post'
             if policy_name_tab[1] == '2':
                 period = 'hc'
                 params['period'] = period
             elif policy_name_tab[1] == '3':
                 period = 'try'
+                method = 'post'
                 if bool_defup:
                     params['actif'] = 'FALSE'
                     msg = 'Active'
@@ -312,12 +314,11 @@ class Customer(object):
                             'code': '204',
                             'message': 'produit non {}'.format(msg)
                             }
-        """if bool_defup:
+        if bool_defup:
             url = core.database_url(**FUPDB_CREDENTIALS)
             with records.Database(url) as db:
                 sql = "DELETE FROM customer WHERE name=:name"
                 db.query(sql, name=self.name)
-        """
         return result
 
     def get_cdr_from_aiguillier(self, last_date):
